# mediqbox

A toolbox for smart medical information processing and application development.

Currently, the toolbox includes the following tools:

* `download`: Download files
* `pubmed`: Query PubMed
* `sendmail`: Send email
